# EC3 Python Wrapper

WORK IN  PROGRESS...COME BACK SOON

This is a Python wrapper for working with the Building Transparency EC3 API.
Documentation for the EC3 API can be found at [https://buildingtransparency.org/ec3/manage-apps/api-doc/api](https://buildingtransparency.org/ec3/manage-apps/api-doc/api)

## Installing

```
pip install ec3-python-wrapper
```

## Documentation

Documentation in Progress at [https://ec3-python-wrapper.readthedocs.io/](https://ec3-python-wrapper.readthedocs.io/)

### Usage Example

A Jupyter Notebook with some examples onf how to use the EC3 Python Wrapper can be found here...

Below are some examples on using the wrapper...